<?php
/**
 * Main class of MegaDebrid.eu plugin
 * @author D.Ducatel
 */
class SynoFileHostingMegaDebrid{

    /**
     * MegaDebrid API URL
     */
    const API_URL = "https://www.mega-debrid.eu/api.php";

    /**
     * URL of file what user want to download (before debrid)
     */
    private $originalUrl;

    /**
     * The username/login of megadebrid.eu
     */
    private $username;

    /**
     * The password of megadebrid.eu
     */
    private $password;

    /**
     * The host information
     */
    private $hostInfo;

    /**
     * The user's token when it's authentificated
     */
    private $userToken;

	/**
	 * True if you want to print message in debug log (system log)
	 */
	private $debugMode;

    /**
     * Constructor (all param are send by the system)
     * @param $url URL of file what user want to download
     * @param $username The username/login of megadebrid.eu premium account
     * @param $password he password of megadebrid.eu premium account
     * @param $hostInfo The host info
     */
    public function __construct($url, $username, $password, $hostInfo){
        $this->originalUrl = $url;
        $this->username = $username;
        $this->password = $password;
        $this->hostInfo = $hostInfo;
        $this->userToken = "";
		$this->debugMode = false;
    }

    /**
     * Debrid the link
     * @warning This is a virtual method
     * @return The debrided link
     */
    public function GetDownloadInfo(){

        $downloadInfo = array();
        if ($this->Verify(false) == LOGIN_FAIL) {
            $downloadInfo[DOWNLOAD_ERROR] = ERR_REQUIRED_PREMIUM;
            $this->logError("Exit on account verify");
            return $downloadInfo;
        }

        $url = self::API_URL . "?action=getLink&token=" . $this->userToken;
        $postdata = http_build_query(array(
            'link' => $this->originalUrl
            ));
        $opts = array(
            'http' => array(
                'method' => 'POST',
                'header' => 'Content-type: application/x-www-form-urlencoded',
                'content' => $postdata
            )
        );

       	$this->logInfo("Debrid link: ".$this->originalUrl. " user token: ".$this->userToken);

        $curl = curl_init();
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($curl, CURLOPT_USERAGENT, DOWNLOAD_STATION_USER_AGENT);
        curl_setopt($curl, CURLOPT_POST, true);
        curl_setopt($curl, CURLOPT_POSTFIELDS, $postdata);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_URL, $url);
        $response = curl_exec($curl);
        $result = json_decode($response);
        curl_close($curl);

        if ($result->{'response_code'} != "ok"){
           $downloadInfo[DOWNLOAD_ERROR] = ERR_NOT_SUPPORT_TYPE;
           $this->logError("Exit on failed debrid: ".$response);
            return $downloadInfo;
        }

        $debridedUrl = substr($result->{'debridLink'}, 1, -1);
        $downloadInfo[DOWNLOAD_URL] = $debridedUrl;
        $downloadInfo[DOWNLOAD_ISPARALLELDOWNLOAD] = true;
        $this->logInfo("End with success: ".$debridedUrl);
        return $downloadInfo;
    }

    /**
     * Verify users account and password
     * @param $ClearCookie
     * @return USER_IS_PREMIUM if user is authentified or LOGIN_FAIL when authentification failed
     */
     public function Verify($ClearCookie){

		$this->logInfo("Verify account");

        if(empty($this->username) || empty($this->password)){
        	$this->logError("Login failed, username or password is empty");
            return LOGIN_FAIL;
        }

        $curl = curl_init();
	$escapedPwd = curl_escape($curl, $this->password);
	$url = self::API_URL . "?action=connectUser&login=" . $this->username . "&password=" . $escapedPwd;
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($curl, CURLOPT_USERAGENT, DOWNLOAD_STATION_USER_AGENT);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_URL, $url);
        $response = curl_exec($curl);
        $result = json_decode($response);
        curl_close($curl);

		$this->logInfo("Verify account url: ".$url);

        if ($result->{'response_code'} == "ok") {
            $this->userToken = $result->{'token'};
            $this->logInfo("User token: ".$this->userToken);
            return USER_IS_PREMIUM;
        }
        else {
        	$this->logError("Login failed: ".$response);
            return LOGIN_FAIL;
        }
    }

	/**
	 * Write an info the message in synology system log
	 * @param $msg The message you want to write
	 */
	private function logInfo($msg) {
		if($this->debugMode)
			system('synologset1 sys info 0x11100000 "[MEGA_DEBRID] '.$msg.'"');
	}

	/**
	 * Write an error the message in synology system log
	 * @param $msg The message you want to write
	 */
	 private function logError($msg) {
	 	if($this->debugMode)
			system('synologset1 sys err 0x11100000 "[MEGA_DEBRID] : '.$msg.'"');
	}
}

?>
